==> haskell-brittany-0.13.1.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brittany.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brittany
version:              0.13.1.0
visibility:           public
id:                   brittany-0.13.1.0-IlCXJuM3G8iK99oTaicP0s
key:                  brittany-0.13.1.0-IlCXJuM3G8iK99oTaicP0s
license:              AGPL-3.0-only
copyright:
    Copyright (C) 2016-2019 Lennart Spitzner
    Copyright (C) 2019 PRODA LTD

maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/brittany/
synopsis:             Haskell source code formatter
description:
    See <https://github.com/lspitzner/brittany/blob/master/README.md the README>.

    If you are interested in the implementation, have a look at <https://github.com/lspitzner/brittany/blob/master/doc/implementation/theory.md this document>;

    The implementation is documented in more detail <https://github.com/lspitzner/brittany/blob/master/doc/implementation/index.md here>.

category:             Language
abi:                  e61ba61e4a89964afc6f15832506f068
exposed:              True
exposed-modules:
    Language.Haskell.Brittany Language.Haskell.Brittany.Internal
    Language.Haskell.Brittany.Internal.Config
    Language.Haskell.Brittany.Internal.Config.Types
    Language.Haskell.Brittany.Internal.Config.Types.Instances
    Language.Haskell.Brittany.Internal.Obfuscation
    Language.Haskell.Brittany.Internal.Prelude
    Language.Haskell.Brittany.Internal.PreludeUtils
    Language.Haskell.Brittany.Internal.Types
    Language.Haskell.Brittany.Internal.Utils
    Language.Haskell.Brittany.Main Paths_brittany

hidden-modules:
    Language.Haskell.Brittany.Internal.LayouterBasics
    Language.Haskell.Brittany.Internal.Backend
    Language.Haskell.Brittany.Internal.BackendUtils
    Language.Haskell.Brittany.Internal.ExactPrintUtils
    Language.Haskell.Brittany.Internal.Layouters.Type
    Language.Haskell.Brittany.Internal.Layouters.Decl
    Language.Haskell.Brittany.Internal.Layouters.Expr
    Language.Haskell.Brittany.Internal.Layouters.Stmt
    Language.Haskell.Brittany.Internal.Layouters.Pattern
    Language.Haskell.Brittany.Internal.Layouters.IE
    Language.Haskell.Brittany.Internal.Layouters.Import
    Language.Haskell.Brittany.Internal.Layouters.Module
    Language.Haskell.Brittany.Internal.Layouters.DataDecl
    Language.Haskell.Brittany.Internal.Transformations.Alt
    Language.Haskell.Brittany.Internal.Transformations.Floating
    Language.Haskell.Brittany.Internal.Transformations.Par
    Language.Haskell.Brittany.Internal.Transformations.Columns
    Language.Haskell.Brittany.Internal.Transformations.Indent

import-dirs:          /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/brittany-0.13.1.0
hs-libraries:         HSbrittany-0.13.1.0-IlCXJuM3G8iK99oTaicP0s
depends:
    Cabal-3.2.1.0 aeson-1.5.6.0-Hdtf8YdIqJe4Gv7Q5rRICM base-4.14.1.0
    butcher-1.3.3.2-KVlIwr1lQyz12juJzgWwA3 bytestring-0.10.12.0
    cmdargs-0.10.21-KlHphs6sBhIECkIRkNdEOM containers-0.6.2.1
    czipwith-1.0.1.3-3vgoVUJklEuJUDH0PLL8nB
    data-tree-print-0.1.0.2-FmnzLNfwDoKEJGxm3cm72t deepseq-1.4.4.0
    directory-1.3.6.0 extra-1.7.9-DKhkhLMAg7NEOzbCisDB9K
    filepath-1.4.2.1 ghc-8.10.4 ghc-boot-th-8.10.4
    ghc-exactprint-0.6.3.4-KarpZzKG71T7pa15LGCRzg
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ
    monad-memo-0.5.3-L1W5boEZjyaEPXp3UsuDUG mtl-2.2.2
    multistate-0.8.0.3-2VdgRHAk3Zg2NijoiLBLgQ pretty-1.1.3.6
    random-1.2.0-JaeEP4ACTucH0elcxqGZLW
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    strict-0.4.0.1-Lbt7zkRh7tfFCV83gLNVD
    syb-0.7.2.1-EJbm1xKwvjzFdTzYxWDoNA text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-LGKKj8diXtZJSESBF6qJCb
    unsafe-0.0-24urQzVt9PWBSwlXDCq1I6
    yaml-0.11.5.0-1NLednkJ1eAEZqLc5f87zx

haddock-interfaces:   /usr/share/doc/haskell-brittany/html/brittany.haddock
haddock-html:         /usr/share/doc/haskell-brittany/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brittany-0.13.1.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brittany.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brittany
version:              0.13.1.0
visibility:           public
id:                   brittany-0.13.1.0-3Aau2ubp0tb2FSmUna2xWN
key:                  brittany-0.13.1.0-3Aau2ubp0tb2FSmUna2xWN
license:              AGPL-3.0-only
copyright:
    Copyright (C) 2016-2019 Lennart Spitzner
    Copyright (C) 2019 PRODA LTD

maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/brittany/
synopsis:             Haskell source code formatter
description:
    See <https://github.com/lspitzner/brittany/blob/master/README.md the README>.

    If you are interested in the implementation, have a look at <https://github.com/lspitzner/brittany/blob/master/doc/implementation/theory.md this document>;

    The implementation is documented in more detail <https://github.com/lspitzner/brittany/blob/master/doc/implementation/index.md here>.

category:             Language
abi:                  47022a86dbca50ef81f402631addf073
exposed:              True
exposed-modules:
    Language.Haskell.Brittany Language.Haskell.Brittany.Internal
    Language.Haskell.Brittany.Internal.Config
    Language.Haskell.Brittany.Internal.Config.Types
    Language.Haskell.Brittany.Internal.Config.Types.Instances
    Language.Haskell.Brittany.Internal.Obfuscation
    Language.Haskell.Brittany.Internal.Prelude
    Language.Haskell.Brittany.Internal.PreludeUtils
    Language.Haskell.Brittany.Internal.Types
    Language.Haskell.Brittany.Internal.Utils
    Language.Haskell.Brittany.Main Paths_brittany

hidden-modules:
    Language.Haskell.Brittany.Internal.LayouterBasics
    Language.Haskell.Brittany.Internal.Backend
    Language.Haskell.Brittany.Internal.BackendUtils
    Language.Haskell.Brittany.Internal.ExactPrintUtils
    Language.Haskell.Brittany.Internal.Layouters.Type
    Language.Haskell.Brittany.Internal.Layouters.Decl
    Language.Haskell.Brittany.Internal.Layouters.Expr
    Language.Haskell.Brittany.Internal.Layouters.Stmt
    Language.Haskell.Brittany.Internal.Layouters.Pattern
    Language.Haskell.Brittany.Internal.Layouters.IE
    Language.Haskell.Brittany.Internal.Layouters.Import
    Language.Haskell.Brittany.Internal.Layouters.Module
    Language.Haskell.Brittany.Internal.Layouters.DataDecl
    Language.Haskell.Brittany.Internal.Transformations.Alt
    Language.Haskell.Brittany.Internal.Transformations.Floating
    Language.Haskell.Brittany.Internal.Transformations.Par
    Language.Haskell.Brittany.Internal.Transformations.Columns
    Language.Haskell.Brittany.Internal.Transformations.Indent

import-dirs:          /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/brittany-0.13.1.0
hs-libraries:         HSbrittany-0.13.1.0-3Aau2ubp0tb2FSmUna2xWN
depends:
    Cabal-3.2.1.0 aeson-1.5.6.0-9524sGJbRH4A0U97UjyMqU base-4.14.1.0
    butcher-1.3.3.2-2kimsTM6yqTBjXvArQYbz2 bytestring-0.10.12.0
    cmdargs-0.10.21-KlHphs6sBhIECkIRkNdEOM containers-0.6.2.1
    czipwith-1.0.1.3-3vgoVUJklEuJUDH0PLL8nB
    data-tree-print-0.1.0.2-FDZZWpB7Y7k1RCvH6ezLws deepseq-1.4.4.0
    directory-1.3.6.0 extra-1.7.9-4Waf3d3XGKX1XwbCNsISVX
    filepath-1.4.2.1 ghc-8.10.4 ghc-boot-th-8.10.4
    ghc-exactprint-0.6.3.4-JCGKsbWYXlU3fLDQuuLnHu
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ
    monad-memo-0.5.3-79Xza7uChREAFmvXBkreTM mtl-2.2.2
    multistate-0.8.0.3-5TJuotfIx2LGb5dvBJ1XT5 pretty-1.1.3.6
    random-1.2.0-CmoPyF0lvWpAFFYiilSJBe
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    strict-0.4.0.1-wMOJbc8Xs81j3udryDnJW
    syb-0.7.2.1-6T61ufUYzPEC9ZKKBvLLoy text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-ZHznx9B7qgk3Zcx9L2VO
    unsafe-0.0-24urQzVt9PWBSwlXDCq1I6
    yaml-0.11.5.0-5YzlvhrHcY8FZ3JjVBIiSp

haddock-interfaces:   /usr/share/doc/haskell-brittany/html/brittany.haddock
haddock-html:         /usr/share/doc/haskell-brittany/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
